@@ -1,26 +1,24 @@
-import os
-from typing import Type
+from typing import Union
 
 import pytest
 from hypothesis import assume, example, given, note
 from hypothesis import strategies as st
 
-from yarl._quoting import NO_EXTENSIONS
+import yarl
+from yarl._quoting import NO_EXTENSIONS, _Quoter, _Unquoter
 from yarl._quoting_py import _Quoter as _PyQuoter
 from yarl._quoting_py import _Unquoter as _PyUnquoter
 
-ENABLE_HYPOTHESIS_TESTS = bool(os.environ.get("ENABLE_HYPOTHESIS_TESTS"))
-
 if not NO_EXTENSIONS:
-    from yarl._quoting_c import _Quoter as _CQuoter
+    from yarl._quoting_c import _Quoter as _CQuoter  # type: ignore[import-not-found]
     from yarl._quoting_c import _Unquoter as _CUnquoter
 
     @pytest.fixture(params=[_PyQuoter, _CQuoter], ids=["py_quoter", "c_quoter"])
-    def quoter(request):
+    def quoter(request: pytest.FixtureRequest) -> Union[_PyQuoter, _CQuoter]:  # type: ignore[misc,no-any-unimported]
         return request.param
 
     @pytest.fixture(params=[_PyUnquoter, _CUnquoter], ids=["py_unquoter", "c_unquoter"])
-    def unquoter(request):
+    def unquoter(request: pytest.FixtureRequest) -> Union[_PyUnquoter, _CUnquoter]:  # type: ignore[misc,no-any-unimported]
         return request.param
 
     quoters = [_PyQuoter, _CQuoter]
@@ -30,12 +28,12 @@ if not NO_EXTENSIONS:
 else:
 
     @pytest.fixture(params=[_PyQuoter], ids=["py_quoter"])
-    def quoter(request):
-        return request.param
+    def quoter(request: pytest.FixtureRequest) -> _PyQuoter:
+        return request.param  # type: ignore[no-any-return]
 
     @pytest.fixture(params=[_PyUnquoter], ids=["py_unquoter"])
-    def unquoter(request):
-        return request.param
+    def unquoter(request: pytest.FixtureRequest) -> _PyUnquoter:
+        return request.param  # type: ignore[no-any-return]
 
     quoters = [_PyQuoter]
     quoter_ids = ["PyQuoter"]
@@ -43,7 +41,12 @@ else:
     unquoter_ids = ["PyUnquoter"]
 
 
-def hexescape(char):
+@pytest.mark.skipif(NO_EXTENSIONS, reason="Extensions available but not imported")
+def test_quoting_c_loaded() -> None:
+    assert "_quoting_c" in dir(yarl)
+
+
+def hexescape(char: str) -> str:
     """Escape char as RFC 2396 specifies"""
     hex_repr = hex(ord(char))[2:].upper()
     if len(hex_repr) == 1:
@@ -51,44 +54,44 @@ def hexescape(char):
     return "%" + hex_repr
 
 
-def test_quote_not_allowed_non_strict(quoter):
+def test_quote_not_allowed_non_strict(quoter: type[_Quoter]) -> None:
     assert quoter()("%HH") == "%25HH"
 
 
-def test_quote_unfinished_tail_percent_non_strict(quoter):
+def test_quote_unfinished_tail_percent_non_strict(quoter: type[_Quoter]) -> None:
     assert quoter()("%") == "%25"
 
 
-def test_quote_unfinished_tail_digit_non_strict(quoter):
+def test_quote_unfinished_tail_digit_non_strict(quoter: type[_Quoter]) -> None:
     assert quoter()("%2") == "%252"
 
 
-def test_quote_unfinished_tail_safe_non_strict(quoter):
+def test_quote_unfinished_tail_safe_non_strict(quoter: type[_Quoter]) -> None:
     assert quoter()("%x") == "%25x"
 
 
-def test_quote_unfinished_tail_unsafe_non_strict(quoter):
+def test_quote_unfinished_tail_unsafe_non_strict(quoter: type[_Quoter]) -> None:
     assert quoter()("%#") == "%25%23"
 
 
-def test_quote_unfinished_tail_non_ascii_non_strict(quoter):
+def test_quote_unfinished_tail_non_ascii_non_strict(quoter: type[_Quoter]) -> None:
     assert quoter()("%ß") == "%25%C3%9F"
 
 
-def test_quote_unfinished_tail_non_ascii2_non_strict(quoter):
+def test_quote_unfinished_tail_non_ascii2_non_strict(quoter: type[_Quoter]) -> None:
     assert quoter()("%€") == "%25%E2%82%AC"
 
 
-def test_quote_unfinished_tail_non_ascii3_non_strict(quoter):
+def test_quote_unfinished_tail_non_ascii3_non_strict(quoter: type[_Quoter]) -> None:
     assert quoter()("%🐍") == "%25%F0%9F%90%8D"
 
 
-def test_quote_from_bytes(quoter):
+def test_quote_from_bytes(quoter: type[_Quoter]) -> None:
     assert quoter()("archaeological arcana") == "archaeological%20arcana"
     assert quoter()("") == ""
 
 
-def test_quote_ignore_broken_unicode(quoter):
+def test_quote_ignore_broken_unicode(quoter: type[_Quoter]) -> None:
     s = quoter()(
         "j\u001a\udcf4q\udcda/\udc97g\udcee\udccb\u000ch\udccb"
         "\u0018\udce4v\u001b\udce2\udcce\udccecom/y\udccepj\u0016"
@@ -98,12 +101,12 @@ def test_quote_ignore_broken_unicode(quoter):
     assert quoter()(s) == s
 
 
-def test_unquote_to_bytes(unquoter):
+def test_unquote_to_bytes(unquoter: type[_Unquoter]) -> None:
     assert unquoter()("abc%20def") == "abc def"
     assert unquoter()("") == ""
 
 
-def test_never_quote(quoter):
+def test_never_quote(quoter: type[_Quoter]) -> None:
     # Make sure quote() does not quote letters, digits, and "_,.-~"
     do_not_quote = (
         "ABCDEFGHIJKLMNOPQRSTUVWXYZ" "abcdefghijklmnopqrstuvwxyz" "0123456789" "_.-~"
@@ -112,7 +115,7 @@ def test_never_quote(quoter):
     assert quoter(qs=True)(do_not_quote) == do_not_quote
 
 
-def test_safe(quoter):
+def test_safe(quoter: type[_Quoter]) -> None:
     # Test setting 'safe' parameter does what it should do
     quote_by_default = "<>"
     assert quoter(safe=quote_by_default)(quote_by_default) == quote_by_default
@@ -128,7 +131,7 @@ SHOULD_QUOTE = "".join(_SHOULD_QUOTE)
 
 
 @pytest.mark.parametrize("char", SHOULD_QUOTE)
-def test_default_quoting(char, quoter):
+def test_default_quoting(char: str, quoter: type[_Quoter]) -> None:
     # Make sure all characters that should be quoted are by default sans
     # space (separate test for that).
     result = quoter()(char)
@@ -138,7 +141,7 @@ def test_default_quoting(char, quoter):
 
 
 # TODO: should it encode percent?
-def test_default_quoting_percent(quoter):
+def test_default_quoting_percent(quoter: type[_Quoter]) -> None:
     result = quoter()("%25")
     assert "%25" == result
     result = quoter(qs=True)("%25")
@@ -147,7 +150,7 @@ def test_default_quoting_percent(quoter):
     assert "%2525" == result
 
 
-def test_default_quoting_partial(quoter):
+def test_default_quoting_partial(quoter: type[_Quoter]) -> None:
     partial_quote = "ab[]cd"
     expected = "ab%5B%5Dcd"
     result = quoter()(partial_quote)
@@ -156,7 +159,7 @@ def test_default_quoting_partial(quoter):
     assert expected == result
 
 
-def test_quoting_space(quoter):
+def test_quoting_space(quoter: type[_Quoter]) -> None:
     # Make sure quote() and quote_plus() handle spaces as specified in
     # their unique way
     result = quoter()(" ")
@@ -173,13 +176,13 @@ def test_quoting_space(quoter):
     assert expect == result
 
 
-def test_quoting_plus(quoter):
+def test_quoting_plus(quoter: type[_Quoter]) -> None:
     assert quoter(qs=False)("alpha+beta gamma") == "alpha+beta%20gamma"
     assert quoter(qs=True)("alpha+beta gamma") == "alpha%2Bbeta+gamma"
     assert quoter(safe="+", qs=True)("alpha+beta gamma") == "alpha+beta+gamma"
 
 
-def test_quote_with_unicode(quoter):
+def test_quote_with_unicode(quoter: type[_Quoter]) -> None:
     # Characters in Latin-1 range, encoded by default in UTF-8
     given = "\u00a2\u00d8ab\u00ff"
     expect = "%C2%A2%C3%98ab%C3%BF"
@@ -192,7 +195,7 @@ def test_quote_with_unicode(quoter):
     assert expect == result
 
 
-def test_quote_plus_with_unicode(quoter):
+def test_quote_plus_with_unicode(quoter: type[_Quoter]) -> None:
     # Characters in Latin-1 range, encoded by default in UTF-8
     given = "\u00a2\u00d8ab\u00ff"
     expect = "%C2%A2%C3%98ab%C3%BF"
@@ -206,7 +209,7 @@ def test_quote_plus_with_unicode(quoter):
 
 
 @pytest.mark.parametrize("num", list(range(128)))
-def test_unquoting(num, unquoter):
+def test_unquoting(num: int, unquoter: type[_Unquoter]) -> None:
     # Make sure unquoting of all ASCII values works
     given = hexescape(chr(num))
     expect = chr(num)
@@ -238,7 +241,9 @@ def test_unquoting(num, unquoter):
         ("%€%3f", "%€?"),
     ],
 )
-def test_unquoting_bad_percent_escapes(unquoter, input, expected):
+def test_unquoting_bad_percent_escapes(
+    unquoter: type[_Unquoter], input: str, expected: str
+) -> None:
     assert unquoter()(input) == expected
 
 
@@ -254,12 +259,14 @@ def test_unquoting_bad_percent_escapes(unquoter, input, expected):
     """,
 )
 @pytest.mark.parametrize("urlencoded_string", ("%AB", "%AB%AB"))
-def test_unquoting_invalid_utf8_sequence(unquoter, urlencoded_string):
+def test_unquoting_invalid_utf8_sequence(
+    unquoter: type[_Unquoter], urlencoded_string: str
+) -> None:
     with pytest.raises(ValueError):
         unquoter()(urlencoded_string)
 
 
-def test_unquoting_mixed_case_percent_escapes(unquoter):
+def test_unquoting_mixed_case_percent_escapes(unquoter: type[_Unquoter]) -> None:
     expected = "𝕦"
     assert expected == unquoter()("%F0%9D%95%A6")
     assert expected == unquoter()("%F0%9d%95%a6")
@@ -267,7 +274,7 @@ def test_unquoting_mixed_case_percent_escapes(unquoter):
     assert expected == unquoter()("%f0%9d%95%a6")
 
 
-def test_unquoting_parts(unquoter):
+def test_unquoting_parts(unquoter: type[_Unquoter]) -> None:
     # Make sure unquoting works when have non-quoted characters
     # interspersed
     given = "ab" + hexescape("c") + "d"
@@ -278,64 +285,64 @@ def test_unquoting_parts(unquoter):
     assert expect == result
 
 
-def test_quote_None(quoter):
+def test_quote_None(quoter: type[_Quoter]) -> None:
     assert quoter()(None) is None
 
 
-def test_unquote_None(unquoter):
+def test_unquote_None(unquoter: type[_Unquoter]) -> None:
     assert unquoter()(None) is None
 
 
-def test_quote_empty_string(quoter):
+def test_quote_empty_string(quoter: type[_Quoter]) -> None:
     assert quoter()("") == ""
 
 
-def test_unquote_empty_string(unquoter):
+def test_unquote_empty_string(unquoter: type[_Unquoter]) -> None:
     assert unquoter()("") == ""
 
 
-def test_quote_bad_types(quoter):
+def test_quote_bad_types(quoter: type[_Quoter]) -> None:
     with pytest.raises(TypeError):
-        quoter()(123)
+        quoter()(123)  # type: ignore[call-overload]
 
 
-def test_unquote_bad_types(unquoter):
+def test_unquote_bad_types(unquoter: type[_Unquoter]) -> None:
     with pytest.raises(TypeError):
-        unquoter()(123)
+        unquoter()(123)  # type: ignore[call-overload]
 
 
-def test_quote_lowercase(quoter):
+def test_quote_lowercase(quoter: type[_Quoter]) -> None:
     assert quoter()("%d1%84") == "%D1%84"
 
 
-def test_quote_unquoted(quoter):
+def test_quote_unquoted(quoter: type[_Quoter]) -> None:
     assert quoter()("%41") == "A"
 
 
-def test_quote_space(quoter):
+def test_quote_space(quoter: type[_Quoter]) -> None:
     assert quoter()(" ") == "%20"  # NULL
 
 
 # test to see if this would work to fix
 # coverage on this file.
-def test_quote_percent_last_character(quoter):
+def test_quote_percent_last_character(quoter: type[_Quoter]) -> None:
     # % is last character in this case.
     assert quoter()("%") == "%25"
 
 
-def test_unquote_unsafe(unquoter):
+def test_unquote_unsafe(unquoter: type[_Unquoter]) -> None:
     assert unquoter(unsafe="@")("%40") == "%40"
 
 
-def test_unquote_unsafe2(unquoter):
+def test_unquote_unsafe2(unquoter: type[_Unquoter]) -> None:
     assert unquoter(unsafe="@")("%40abc") == "%40abc"
 
 
-def test_unquote_unsafe3(unquoter):
+def test_unquote_unsafe3(unquoter: type[_Unquoter]) -> None:
     assert unquoter(qs=True)("a%2Bb=?%3D%2B%26") == "a%2Bb=?%3D%2B%26"
 
 
-def test_unquote_unsafe4(unquoter):
+def test_unquote_unsafe4(unquoter: type[_Unquoter]) -> None:
     assert unquoter(unsafe="@")("a@b") == "a%40b"
 
 
@@ -350,145 +357,167 @@ def test_unquote_unsafe4(unquoter):
         ("%e2%82%e2%82", "%e2%82%e2%82"),
     ],
 )
-def test_unquote_non_utf8(unquoter, input, expected):
+def test_unquote_non_utf8(unquoter: type[_Unquoter], input: str, expected: str) -> None:
     assert unquoter()(input) == expected
 
 
-def test_unquote_unsafe_non_utf8(unquoter):
+def test_unquote_unsafe_non_utf8(unquoter: type[_Unquoter]) -> None:
     assert unquoter(unsafe="\n")("%e2%82%0a") == "%e2%82%0A"
 
 
-def test_unquote_plus_non_utf8(unquoter):
+def test_unquote_plus_non_utf8(unquoter: type[_Unquoter]) -> None:
     assert unquoter(qs=True)("%e2%82%2b") == "%e2%82%2B"
 
 
-def test_quote_non_ascii(quoter):
+def test_quote_non_ascii(quoter: type[_Quoter]) -> None:
     assert quoter()("%F8") == "%F8"
 
 
-def test_quote_non_ascii2(quoter):
+def test_quote_non_ascii2(quoter: type[_Quoter]) -> None:
     assert quoter()("a%F8b") == "a%F8b"
 
 
-def test_quote_percent_percent_encoded(quoter):
+def test_quote_percent_percent_encoded(quoter: type[_Quoter]) -> None:
     assert quoter()("%%3f") == "%25%3F"
 
 
-def test_quote_percent_digit_percent_encoded(quoter):
+def test_quote_percent_digit_percent_encoded(quoter: type[_Quoter]) -> None:
     assert quoter()("%2%3f") == "%252%3F"
 
 
-def test_quote_percent_safe_percent_encoded(quoter):
+def test_quote_percent_safe_percent_encoded(quoter: type[_Quoter]) -> None:
     assert quoter()("%x%3f") == "%25x%3F"
 
 
-def test_quote_percent_unsafe_percent_encoded(quoter):
+def test_quote_percent_unsafe_percent_encoded(quoter: type[_Quoter]) -> None:
     assert quoter()("%#%3f") == "%25%23%3F"
 
 
-def test_quote_percent_non_ascii_percent_encoded(quoter):
+def test_quote_percent_non_ascii_percent_encoded(quoter: type[_Quoter]) -> None:
     assert quoter()("%ß%3f") == "%25%C3%9F%3F"
 
 
-def test_quote_percent_non_ascii2_percent_encoded(quoter):
+def test_quote_percent_non_ascii2_percent_encoded(quoter: type[_Quoter]) -> None:
     assert quoter()("%€%3f") == "%25%E2%82%AC%3F"
 
 
-def test_quote_percent_non_ascii3_percent_encoded(quoter):
+def test_quote_percent_non_ascii3_percent_encoded(quoter: type[_Quoter]) -> None:
     assert quoter()("%🐍%3f") == "%25%F0%9F%90%8D%3F"
 
 
+def test_quote_starts_with_percent(quoter: type[_Quoter]) -> None:
+    assert quoter()("%a") == "%25a"
+
+
+def test_quote_ends_with_percent(quoter: type[_Quoter]) -> None:
+    assert quoter()("a%") == "a%25"
+
+
+def test_quote_all_percent(quoter: type[_Quoter]) -> None:
+    assert quoter()("%%%%") == "%25%25%25%25"
+
+
 class StrLike(str):
-    pass
+    """Str subclass."""
 
 
-def test_quote_str_like(quoter):
+def test_quote_str_like(quoter: type[_Quoter]) -> None:
     assert quoter()(StrLike("abc")) == "abc"
 
 
-def test_unquote_str_like(unquoter):
+def test_unquote_str_like(unquoter: type[_Unquoter]) -> None:
     assert unquoter()(StrLike("abc")) == "abc"
 
 
-def test_quote_sub_delims(quoter):
+def test_quote_sub_delims(quoter: type[_Quoter]) -> None:
     assert quoter()("!$&'()*+,;=") == "!$&'()*+,;="
 
 
-def test_requote_sub_delims(quoter):
+def test_requote_sub_delims(quoter: type[_Quoter]) -> None:
     assert quoter()("%21%24%26%27%28%29%2A%2B%2C%3B%3D") == "!$&'()*+,;="
 
 
-def test_unquoting_plus(unquoter):
+def test_unquoting_plus(unquoter: type[_Unquoter]) -> None:
     assert unquoter(qs=False)("a+b") == "a+b"
 
 
-def test_unquote_plus_to_space(unquoter):
+def test_unquote_plus_to_space(unquoter: type[_Unquoter]) -> None:
     assert unquoter(qs=True)("a+b") == "a b"
 
 
-def test_unquote_plus_to_space_unsafe(unquoter):
+def test_unquote_with_plus_plus_to_space(unquoter: type[_Unquoter]) -> None:
+    assert unquoter(plus=True)("a+b") == "a b"
+
+
+def test_unquote_without_plus_plus(unquoter: type[_Unquoter]) -> None:
+    assert unquoter(plus=False)("a+b") == "a+b"
+
+
+def test_unquote_plus_to_space_unsafe(unquoter: type[_Unquoter]) -> None:
     assert unquoter(unsafe="+", qs=True)("a+b") == "a+b"
 
 
-def test_quote_qs_with_colon(quoter):
+def test_unquote_multiple_unsafe(unquoter: type[_Unquoter]) -> None:
+    assert unquoter(unsafe="!@#$")("a!@#$b") == "a%21%40%23%24b"
+
+
+def test_unquote_explict_empty_unsafe(unquoter: type[_Unquoter]) -> None:
+    assert unquoter(unsafe="")("a!@#$b") == "a!@#$b"
+
+
+def test_quote_qs_with_colon(quoter: type[_Quoter]) -> None:
     s = quoter(safe="=+&?/:@", qs=True)("next=http%3A//example.com/")
     assert s == "next=http://example.com/"
 
 
-def test_quote_protected(quoter):
+def test_quote_protected(quoter: type[_Quoter]) -> None:
     s = quoter(protected="/")("/path%2fto/three")
     assert s == "/path%2Fto/three"
 
 
-def test_quote_fastpath_safe(quoter):
+def test_quote_fastpath_safe(quoter: type[_Quoter]) -> None:
     s1 = "/path/to"
     s2 = quoter(safe="/")(s1)
     assert s1 is s2
 
 
-def test_quote_fastpath_pct(quoter):
+def test_quote_fastpath_pct(quoter: type[_Quoter]) -> None:
     s1 = "abc%A0"
     s2 = quoter()(s1)
     assert s1 is s2
 
 
-def test_quote_very_large_string(quoter):
+def test_quote_very_large_string(quoter: type[_Quoter]) -> None:
     # more than 8 KiB
     s = "abcфух%30%0a" * 1024
     assert quoter()(s) == "abc%D1%84%D1%83%D1%850%0A" * 1024
 
 
-def test_space(quoter):
+def test_space(quoter: type[_Quoter]) -> None:
     s = "% A"
     assert quoter()(s) == "%25%20A"
 
 
-def test_quoter_path_with_plus(quoter):
+def test_quoter_path_with_plus(quoter: type[_Quoter]) -> None:
     s = "/test/x+y%2Bz/:+%2B/"
     assert "/test/x+y%2Bz/:+%2B/" == quoter(safe="@:", protected="/+")(s)
 
 
-def test_unquoter_path_with_plus(unquoter):
+def test_unquoter_path_with_plus(unquoter: type[_Unquoter]) -> None:
     s = "/test/x+y%2Bz/:+%2B/"
     assert "/test/x+y+z/:++/" == unquoter(unsafe="+")(s)
 
 
 @given(safe=st.text(), protected=st.text(), qs=st.booleans(), requote=st.booleans())
-@pytest.mark.skipif(
-    not ENABLE_HYPOTHESIS_TESTS, reason="hypothesis tests are not enabled"
-)
-def test_fuzz__PyQuoter(safe, protected, qs, requote):
+def test_fuzz__PyQuoter(safe: str, protected: str, qs: bool, requote: bool) -> None:  # type: ignore[misc]
     """Verify that _PyQuoter can be instantiated with any valid arguments."""
-    assert _PyQuoter(safe=safe, protected=protected, qs=qs, requote=requote)
+    _PyQuoter(safe=safe, protected=protected, qs=qs, requote=requote)
 
 
 @given(ignore=st.text(), unsafe=st.text(), qs=st.booleans())
-@pytest.mark.skipif(
-    not ENABLE_HYPOTHESIS_TESTS, reason="hypothesis tests are not enabled"
-)
-def test_fuzz__PyUnquoter(ignore, unsafe, qs):
+def test_fuzz__PyUnquoter(ignore: str, unsafe: str, qs: bool) -> None:  # type: ignore[misc]
     """Verify that _PyUnquoter can be instantiated with any valid arguments."""
-    assert _PyUnquoter(ignore=ignore, unsafe=unsafe, qs=qs)
+    _PyUnquoter(ignore=ignore, unsafe=unsafe, qs=qs)
 
 
 @example(text_input="0")
@@ -497,14 +526,11 @@ def test_fuzz__PyUnquoter(ignore, unsafe, qs):
         alphabet=st.characters(max_codepoint=127, blacklist_characters="%")
     ),
 )
-@pytest.mark.skipif(
-    not ENABLE_HYPOTHESIS_TESTS, reason="hypothesis tests are not enabled"
-)
 @pytest.mark.parametrize("quoter", quoters, ids=quoter_ids)
 @pytest.mark.parametrize("unquoter", unquoters, ids=unquoter_ids)
-def test_quote_unquote_parameter(
-    quoter: Type[_PyQuoter],
-    unquoter: Type[_PyUnquoter],
+def test_quote_unquote_parameter(  # type: ignore[misc]
+    quoter: type[_PyQuoter],
+    unquoter: type[_PyUnquoter],
     text_input: str,
 ) -> None:
     quote = quoter()
@@ -521,14 +547,11 @@ def test_quote_unquote_parameter(
         alphabet=st.characters(max_codepoint=127, blacklist_characters="%")
     ),
 )
-@pytest.mark.skipif(
-    not ENABLE_HYPOTHESIS_TESTS, reason="hypothesis tests are not enabled"
-)
 @pytest.mark.parametrize("quoter", quoters, ids=quoter_ids)
 @pytest.mark.parametrize("unquoter", unquoters, ids=unquoter_ids)
-def test_quote_unquote_parameter_requote(
-    quoter: Type[_PyQuoter],
-    unquoter: Type[_PyUnquoter],
+def test_quote_unquote_parameter_requote(  # type: ignore[misc]
+    quoter: type[_PyQuoter],
+    unquoter: type[_PyUnquoter],
     text_input: str,
 ) -> None:
     quote = quoter(requote=True)
@@ -545,14 +568,11 @@ def test_quote_unquote_parameter_requote(
         alphabet=st.characters(max_codepoint=127, blacklist_characters="%")
     ),
 )
-@pytest.mark.skipif(
-    not ENABLE_HYPOTHESIS_TESTS, reason="hypothesis tests are not enabled"
-)
 @pytest.mark.parametrize("quoter", quoters, ids=quoter_ids)
 @pytest.mark.parametrize("unquoter", unquoters, ids=unquoter_ids)
-def test_quote_unquote_parameter_path_safe(
-    quoter: Type[_PyQuoter],
-    unquoter: Type[_PyUnquoter],
+def test_quote_unquote_parameter_path_safe(  # type: ignore[misc]
+    quoter: type[_PyQuoter],
+    unquoter: type[_PyUnquoter],
     text_input: str,
 ) -> None:
     quote = quoter()
